@@ -10,7 +10,7 @@ use Rose::DB::Object::Metadata::UniqueKey;
 use Rose::DB::Object::Metadata::Auto;
 our @ISA = qw(Rose::DB::Object::Metadata::Auto);
 
-our $VERSION = '0.73';
+our $VERSION = '0.756';
 
 sub auto_generate_unique_keys
 {
@@ -112,7 +112,7 @@ WHERE
   REFERENCED_TABLE_NAME IS NOT NULL AND
   TABLE_SCHEMA = ? AND TABLE_NAME = ?
 ORDER BY
-  REFERENCED_TABLE_SCHEMA, REFERENCED_TABLE_NAME
+  REFERENCED_TABLE_SCHEMA, REFERENCED_TABLE_NAME, CONSTRAINT_NAME
 EOF
         $sth->execute($db_name, $self->table);
 
@@ -123,21 +123,24 @@ EOF
         $sth->bind_columns(\($constraint_catalog, $constraint_schema, $constraint_name,
                              $table_catalog, $table_schema, $table_name, $local_column,
                              $foreign_schema, $foreign_table, $foreign_column));
-        my %fk_info;
+        my($current_constraint, %fk_info);
 
         while($sth->fetch)
         {
           # No cross-database foreign keys in MySQL for now...
           next  unless(!defined $foreign_schema || lc $foreign_schema eq lc $db_name);
 
-          my $info = $fk_info{$foreign_table} ||= {};
+          my $info = $fk_info{$constraint_name} ||= { foreign_table => $foreign_table };
 
           push(@{$info->{'local_columns'}}, $local_column);
           push(@{$info->{'foreign_columns'}}, $foreign_column);
         }
 
-        FK: while(my($foreign_table, $info) = each %fk_info)
+        my $cm = $self->convention_manager;
+
+        FK: while(my($constraint_name, $info) = each %fk_info)
         {
+          my $foreign_table   = $info->{'foreign_table'};
           my @local_columns   = @{$info->{'local_columns'}};
           my @foreign_columns = @{$info->{'foreign_columns'}};
 
@@ -188,6 +191,7 @@ EOF
 
           my $fk = 
             Rose::DB::Object::Metadata::ForeignKey->new(
+              name        => $constraint_name,
               class       => $foreign_class,
               key_columns => \%key_columns);
 
@@ -301,6 +305,7 @@ EOF
 
             my $fk = 
               Rose::DB::Object::Metadata::ForeignKey->new(
+                name        => $constraint_name,
                 class       => $foreign_class,
                 key_columns => \%key_columns);
 
@@ -320,19 +325,27 @@ EOF
       sort { lc $a->class->meta->table cmp lc $b->class->meta->table } 
       @foreign_keys;
 
+    my %used_names;
+
     foreach my $fk (@foreign_keys)
     {
-      my $key_name = 
-        $cm->auto_foreign_key_name($fk->class) ||
-        $self->foreign_key_name_generator->($self, $fk);
+      my $name =
+        $cm->auto_foreign_key_name($fk->class, $fk->name, scalar $fk->key_columns, \%used_names);
 
-      unless(defined $key_name && $key_name =~ /^\w+$/)
+      unless(defined $name)
       {
-        die "Missing or invalid key name '$key_name' for foreign key ",
+        $fk->name($name = $self->foreign_key_name_generator->($self, $fk));
+      }
+
+      unless(defined $name && $name =~ /^\w+$/)
+      {
+        die "Missing or invalid key name '$name' for foreign key ",
             "generated in $class for ", $fk->class;
       }
 
-      $fk->name($key_name);
+      $used_names{$name}++;
+
+      $fk->name($name);
     }
   };
 
