@@ -2,6 +2,10 @@ package Rose::DB::Object::Util;
 
 use strict;
 
+use Carp;
+
+use Rose::DB::Object::Helpers();
+
 use Rose::DB::Object::Constants
   qw(PRIVATE_PREFIX STATE_IN_DB STATE_LOADING STATE_SAVING MODIFIED_COLUMNS);
 
@@ -14,7 +18,8 @@ our @EXPORT_OK =
      unset_state_in_db unset_state_loading unset_state_saving
      row_id column_value_formatted_key column_value_is_inflated_key
      lazy_column_values_loaded_key modified_column_names has_modified_columns
-     set_column_value_modified get_column_value_modified);
+     has_modified_children has_loaded_related set_column_value_modified
+     unset_column_value_modified get_column_value_modified);
 
 our %EXPORT_TAGS = 
 (
@@ -23,10 +28,12 @@ our %EXPORT_TAGS =
   set_state   => [ qw(set_state_in_db set_state_loading set_state_saving) ],
   unset_state => [ qw(unset_state_in_db unset_state_loading unset_state_saving) ],
   columns     => [ qw(set_column_value_modified get_column_value_modified 
-                      modified_column_names has_modified_columns) ],
+                      unset_column_value_modified modified_column_names 
+                      has_modified_columns) ],
+  children    => [ qw(has_modified_children has_loaded_related) ],
 );
 
-our $VERSION = '0.73';
+our $VERSION = '0.756';
 
 sub is_in_db   { shift->{STATE_IN_DB()}   }
 sub is_loading { shift->{STATE_LOADING()} }
@@ -52,6 +59,12 @@ sub set_column_value_modified
   return $object->{MODIFIED_COLUMNS()}{$name} = 1;
 }
 
+sub unset_column_value_modified
+{
+  my($object, $name) = (shift, shift);
+  return delete $object->{MODIFIED_COLUMNS()}{$name};
+}
+
 sub modified_column_names
 {
   keys(%{shift->{MODIFIED_COLUMNS()} || {}});
@@ -67,6 +80,53 @@ sub has_modified_columns
   scalar %{shift->{MODIFIED_COLUMNS()} || {}}
 }
 
+sub has_loaded_related 
+{
+  if(@_ == 2) # $object, $name
+  {
+    return Rose::DB::Object::Helpers::has_loaded_related(@_);
+  }
+
+  my %args = @_;
+  my $object = delete $args{'object'} or croak "Missing object parameter";
+
+  Rose::DB::Object::Helpers::has_loaded_related($object, %args);
+}
+
+sub has_modified_children
+{
+  my($self) = shift;
+
+  my $meta = $self->meta;
+
+  foreach my $fk ($meta->foreign_keys)
+  {
+    my $foreign_object = $fk->object_has_foreign_object($self) || next;
+
+    if(has_modified_columns($foreign_object) || 
+       has_modified_children($foreign_object))
+    {
+      return 1;
+    }
+  }
+
+  foreach my $rel ($meta->relationships)
+  {
+    my $related_objects = $rel->object_has_related_objects($self) || next;
+
+    foreach my $rel_object (@$related_objects)
+    {
+      if(has_modified_columns($rel_object) || 
+         has_modified_children($rel_object))
+      {
+        return 1;
+      }
+    }
+  }
+
+  return 0;
+}
+
 # XXX: A value that is unlikely to exist in a primary key column value
 use constant PK_JOIN => "\0\2,\3\0";
 
@@ -74,7 +134,7 @@ sub row_id
 {
   my($object) = shift;
 
-  my $meta = $object->meta or die "$object has no meta attribute";
+  my $meta = $object->meta or croak "$object has no meta attribute";
 
   return 
     join(PK_JOIN, 
@@ -180,9 +240,19 @@ will cause the following function names to be imported:
 
     get_column_value_modified()
     set_column_value_modified()
+    unset_column_value_modified()
     modified_column_names()
     has_modified_columns()
 
+The 'children' tag:
+
+    use Rose::DB::Object::Util qw(:children);
+
+will cause the following function names to be imported:
+
+    has_loaded_related()
+    has_modified_children()
+
 The 'all' tag:
 
     use Rose::DB::Object::Util qw(:all);
@@ -203,9 +273,13 @@ will cause the following function names to be imported:
 
     get_column_value_modified()
     set_column_value_modified()
+    unset_column_value_modified()
     modified_column_names()
     has_modified_columns()
 
+    has_loaded_related()
+    has_modified_children()
+
 =head1 FUNCTIONS
 
 =over 4
@@ -214,6 +288,23 @@ will cause the following function names to be imported:
 
 Returns true if the column named COLUMN in OBJECT is modified, false otherwise.
 
+=item B<has_loaded_related [ OBJECT, NAME | PARAMS ]>
+
+Given an OBJECT and a foreign key or relationship name, return true if one or more related objects have been loaded into OBJECT, false otherwise.
+
+If the name is passed as a plain string NAME, then a foreign key with that name is looked up.  If no such foreign key exists, then a relationship with that name is looked up.  If no such relationship or foreign key exists, a fatal error will occur.  Example:
+
+    has_loaded_related($object, 'bar');
+
+It's generally not a good idea to add a foreign key and a relationship with the same name, but it is technically possible.  To specify the domain of the name, pass the name as the value of a C<foreign_key> or C<relationship> parameter.  You must also pass the object as the value of the C<object> parameter.  Example:
+
+    has_loaded_related(object => $object, foreign_key => 'bar');
+    has_loaded_related(object => $object, relationship => 'bar');
+
+=item B<has_modified_children OBJECT>
+
+Returns true if OBJECT L<has_loaded_related|/has_loaded_related> objects, at least one of which L<has_modified_columns|/has_modified_columns> or L<has_modified_children|/has_modified_children>, false otherwise.
+
 =item B<has_modified_columns OBJECT>
 
 Returns true if OBJECT has any modified columns, false otherwise.
@@ -238,6 +329,10 @@ Returns a list containing the names of all the modified columns in OBJECT.
 
 Mark the column named COLUMN in OBJECT as modified.
 
+=item B<unset_column_value_modified OBJECT, COLUMN>
+
+Clear the modified mark, if any, on the column named COLUMN in OBJECT.
+
 =item B<set_state_in_db OBJECT>
 
 Mark the L<Rose::DB::Object>-derived object OBJECT as having been L<load|Rose::DB::Object/load>ed from or L<save|Rose::DB::Object/save>d into the database at some point in the past.
